@@ -7,7 +7,8 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
                             doquan, qlevels, quantiletype, doilevels, ilevels, iglevels, domvpa,
                             mvpathreshold, boutcriter, closedbout,
                             bout.metric, mvpadur, mvpanames, wdaycode, IDd, ID, ID2,
-                            deviceSerialNumber, qM5L5, ExtFunColsi, myfun) {
+                            deviceSerialNumber, qM5L5, ExtFunColsi, myfun, desiredtz="",
+                            MX.ig.min.dur=10) {
   if (length(selectdaysfile) > 0 & ndays == 2) {
     ndays = 1
     startatmidnight = endatmidnight  = 1
@@ -43,10 +44,36 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
   }
   #===============================================
   # Features per day (based on on single variables)
-  qwindowbackup = qwindow
+  qwindow_names = qwindowbackup = qwindow
+  qwindow_actlog =FALSE
+  if (is.data.frame(qwindow) == TRUE) {
+    qwindow_actlog =TRUE  
+  }
+  unique_dates_recording = unique(as.Date(iso8601chartime2POSIX(time[c(seq(1, length(time), by = (3600/ws2)*12),length(time))], tz=desiredtz)))
   for (di in 1:ndays) { #run through days
     qwindow = qwindowbackup
-    #extract day from matrix D and qcheck
+    if (is.data.frame(qwindow) == TRUE) {
+      currentdate = which(qwindow$date == unique_dates_recording[di])
+      if (length(currentdate) > 0) {
+        qwindow_times = as.character(unlist(qwindow$qwindow_times[currentdate]))
+        qwindow_names = as.character(unlist(qwindow$qwindow_names[currentdate]))
+        qwindow = qwindow_values_backup = unlist(qwindow$qwindow_values[currentdate])
+      }
+      if (length(qwindow) == 1) qwindow = c()
+      if (length(qwindow) == 0 | length(currentdate) == 0)  {
+        qwindow_times = c("00:00","24:00")
+        qwindow_names = c("daystart","dayend")
+        qwindow = qwindow_values_backup = c(0, 24)
+      } 
+    } else {
+      if (length(qwindow) == 0) {
+        qwindow = c(0, 24)
+      }
+      qwindow_values_backup = qwindow
+      qwindow_times = as.character(qwindow)
+      qwindow_names = as.character(qwindow)
+    }
+    # extract day from matrix D and qcheck
     if (length(selectdaysfile) > 0 & startatmidnight == 1 & endatmidnight == 1) { #added on 14/9/2016
       qqq1 = 1#midnightsi[di]*(ws2/ws3) 	#a day starts at 00:00
       qqq2 = midnightsi[di]*(ws2/ws3) #(midnightsi[(di+1)]*(ws2/ws3))-1
@@ -55,9 +82,9 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
       qqq2 = (midnightsi[(di+1)]*(ws2/ws3))-1
     } else if (startatmidnight == 1 & endatmidnight == 0) {
       if (di < floor(ndays)) { #applying floor because when day there is day saving time then ndays is not an integer
-        qqq1 = (midnightsi[di]-1)*(ws2/ws3)
-        qqq2 = ((midnightsi[(di+1)]-1)*(ws2/ws3))+1
-      } else if (di == floor(ndays)) {
+        qqq1 = (midnightsi[di]-1)*(ws2/ws3) + 1
+        qqq2 = ((midnightsi[(di+1)]-1)*(ws2/ws3))  #remove +1 because I got some extra seconds per day
+} else if (di == floor(ndays)) {
         qqq1 = (midnightsi[di]-1)*(ws2/ws3)
         qqq2 = nrow(metashort)
       }
@@ -110,10 +137,10 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
     deltaLengthQwindow = 0
     if (length(qwindow) < 2) qwindow = c()
     if (length(qwindow) > 0) {
-      if (length(qwindowbackup) == 1) {
+      if (length(qwindow_names) == 1) {
         cat("Argument to qwindow is invalid, requires a vector of at least length 2")
       }
-      if (length(qwindowbackup) == 2) {
+      if (length(qwindow_names) == 2) {
         if (qwindow[1] != 0 | qwindow[2] != 24) {
           if((qwindowindices[2]*60*(60/ws3)) <= length(val)) {
             valq = val[((qwindowindices[1]*60*(60/ws3))+1):(qwindowindices[2]*60*(60/ws3))]
@@ -123,8 +150,8 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
           nvalidhours_qwindow =length(which(valq == 0))/ (3600/ws3)
           nhours_qwindow = length(valq)/ (3600/ws3) #valid hours per day (or half a day)
         }
-      } else if (length(qwindowbackup) > 2) {
-        deltaLengthQwindow = length(qwindowbackup) - length(qwindowindices)
+      } else if (length(qwindow_names) > 2) {
+        deltaLengthQwindow = length(qwindow_names) - length(qwindowindices)
         for (qwi in 1:(length(qwindowindices)-1)) { #
           startindex = qwindowindices[qwi]*60*(60/ws3)
           endindex = qwindowindices[qwi+1]*60*(60/ws3)
@@ -139,8 +166,8 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
             nvalidhours_qwindow[qwi + deltaLengthQwindow] =length(which(valq == 0))/ (3600/ws3)
             nhours_qwindow[qwi + deltaLengthQwindow] = length(valq)/ (3600/ws3) #valid hours per day (or half a day)
           } else {
-            nvalidhours_qwindow[qwi + deltaLengthQwindow] = 0
-            nhours_qwindow[qwi + deltaLengthQwindow] = 0 #valid hours per day (or half a day)
+            nvalidhours_qwindow[qwi + deltaLengthQwindow] = ""
+            nhours_qwindow[qwi + deltaLengthQwindow] = "" #valid hours per day (or half a day)
           }
         }
       }
@@ -173,24 +200,41 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
     fi = fi + 4
     if (length(qwindow > 0)) {
       if (length(qwindow) > 2 | qwindow[1] != 0 | qwindow[2] != 24) {
-        for (qwi in 1:(length(qwindowbackup)-1)) { # create variables regardless of
-          if (length(which(qwindowbackup[qwi] %in% qwindow == TRUE)) > 0) {
-            daysummary[di,(fi)] = nvalidhours_qwindow[qwi]
-            daysummary[di,(fi+1)] = nhours_qwindow[qwi]
-          } else {
-            daysummary[di,(fi)] = 0 # note that we only consider qwindows when there is data for the entire window, otherwise duration is 0
-            daysummary[di,(fi+1)] = 0
+        for (qwi in 1:(length(qwindow_names)-1)) { # create variables regardless of
+          tmp_name = c(paste0("N_valid_hours_",qwindow_names[qwi],"-",qwindow_names[qwi+1],"hr"),
+                       paste0("N_hours_",qwindow_names[qwi],"-",qwindow_names[qwi+1],"hr"))
+          matchi1 = which(ds_names %in% tmp_name[1] == TRUE)
+          matchi2 = which(ds_names %in% tmp_name[2] == TRUE)
+          if (length(matchi1) == 1 & length(matchi2) == 1) {
+            ds_names[matchi1] == tmp_name[1]
+            ds_names[matchi2] == tmp_name[2]
+            if (length(which(qwindow_values_backup[qwi] %in% qwindow == TRUE)) > 0) {
+              daysummary[di,matchi1] = nvalidhours_qwindow[qwi]
+              daysummary[di,matchi2] = nhours_qwindow[qwi]
+            } else {
+              daysummary[di,matchi1] = "" # note that we only consider qwindows when there is data for the entire window, otherwise duration is 0
+              daysummary[di,matchi2] = ""
+            }
+            fi = fi + 2
+          } else {  # variable does not exists, so add it,
+            ds_names = c(ds_names,tmp_name)
+            daysummary = cbind(daysummary, matrix("",nrow(daysummary),2))
+            newncol = ncol(daysummary)
+            if (length(which(qwindow_values_backup[qwi] %in% qwindow == TRUE)) > 0) {
+              daysummary[di, (newncol-1):newncol] = c(nvalidhours_qwindow[qwi], nhours_qwindow[qwi])
+            } else {
+              daysummary[di, (newncol-1):newncol] = c("", "")
+            }
           }
-          ds_names[fi:(fi+1)] = c(paste0("N_valid_hours_",qwindowbackup[qwi],"-",qwindowbackup[qwi+1],"hr"),
-                                  paste0("N_hours_",qwindowbackup[qwi],"-",qwindowbackup[qwi+1],"hr"))
-          fi = fi + 2
         }
       }
     }
-    
+    if (di > 1 & length(which(ds_names == "weekday")) > 0) { #qwindow_actlog == TRUE &
+      fi = which(ds_names == "weekday")
+    }
     #--------------------------------------
     weekdays = c("Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday")
-    weekdays = rep(weekdays,26) # hardcoded maximum number of weeks of 26, not ideal
+    weekdays = rep(weekdays, 104) # hardcoded maximum number of weeks of 104, not ideal
     if (di == 1) {
       daysummary[di,fi] = wdayname
     } else {
@@ -199,6 +243,14 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
     daysummary[di,(fi+1)] = di #day number relative to start of measurement
     ds_names[fi:(fi+1)] = c("weekday","measurementday")
     fi = fi + 2
+    if (qwindow_actlog == TRUE | length(qwindow) > 2) { # add column with all timestamps in single character
+      ds_names[fi] =  "qwindow_timestamps"
+      daysummary[di,fi] = paste0(qwindow_times,collapse="_")
+      fi = fi + 1
+      ds_names[fi] =  "qwindow_names"
+      daysummary[di,fi] = paste0(qwindow_names,collapse="_")
+      fi = fi + 1
+    }
     if (length(selectdaysfile) > 0) {
       #---------------------------
       # Description per timewindow for millenium cohort:
@@ -236,6 +288,19 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
       }
       gikb = gikb + gik
     }
+    correct_fi = function(di, ds_names, fi, varname) {
+      # function to reset variable index to allign with previous day
+      if (di > 1) {
+        varexists = which(ds_names == varname)
+        if (length(varexists) > 0) {
+          fi = varexists
+        } else {
+          fi = which(ds_names == "")[1]
+        }
+      }
+      return(fi)
+    }
+    
     if (tooshort == 0) {
       if (nvalidhours >= includedaycrit) {
         #--------------------------------------
@@ -255,7 +320,7 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
             anwi_t0 = c(anwi_t0,((qwindowindices[oddqwindow]*60*(60/ws3))+1))
             anwi_t1 = c(anwi_t1,(qwindowindices[evenqwindow]*60*(60/ws3)))
             for (iin in 1:length(oddqwindow)) {
-              anwi_nameindices = c(anwi_nameindices,paste0("_",qwindow[oddqwindow[iin]],"-",qwindow[evenqwindow[iin]],"hr"))
+              anwi_nameindices = c(anwi_nameindices,paste0("_",qwindow_names[oddqwindow[iin]],"-",qwindow_names[evenqwindow[iin]],"hr"))
             }
           }
         } else {
@@ -265,7 +330,7 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
         }
         fi_remember = fi
         for (anwi_index in 1:length(anwi_t0)) {
-          if(anwi_index == 2 & di == 1) {
+          if(anwi_index != 1 & di == 1) {
             # increase value of fi to leave enough space for the variables to be calculated in second day of measurement
             shift = (deltaLengthQwindow * (fi-fi_remember))
             fi = fi + shift
@@ -301,30 +366,58 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
               # Starting filling output matrix daysummary with variables per day segment and full day.
               if (mi == ENMOi | mi == LFENMOi | mi == BFENi |
                   mi == ENi | mi == HFENi | mi == HFENplusi | mi == MADi | mi == ENMOai) {
+                collectfi =c()
+                for (winhr_value in winhr) { # Variable (column) names
+                  # We are first defining location of variable names, before calculating
+                  # variables
+                  ML5colna = c(paste0("L",winhr_value,"hr"), paste0("L",winhr_value), 
+                               paste0("M",winhr_value,"hr"), paste0("M",winhr_value))
+                  if (length(iglevels) > 0 & length(MX.ig.min.dur) == 1) { # intensity gradient (as described by Alex Rowlands 2018)
+                    if (winhr_value >= MX.ig.min.dur) {
+                      for (li in 1:2) { # do twice, once for LX and once for MX
+                        varnameig = paste0(paste0(ifelse(li == 1, yes = "L", no = "M"),winhr_value,"_"),c("ig_gradient","ig_intercept","ig_rsquared"))
+                        ML5colna = c(ML5colna, varnameig)
+                      }
+                    }
+                  }
+                  if (length(qM5L5) > 0) {
+                    ML5colna = c(ML5colna,
+                                 paste0("L",winhr_value,"_q",round(qM5L5 *100)), 
+                                 paste0("M",winhr_value,"_q",round(qM5L5 *100)))
+                  }
+                  # add metric name and timewindow name
+                  fi = correct_fi(di, ds_names, fi, varname = paste0(ML5colna[1],"_", colnames(metashort)[mi], "_mg",L5M5window_name))
+                  ds_names[fi:(fi-1+length(ML5colna))] = paste0(ML5colna,"_", colnames(metashort)[mi], "_mg",L5M5window_name)
+                  collectfi = c(collectfi,fi)
+                  fi=fi+length(ML5colna)
+                }
                 if (length(varnum) > ((60/ws3)*60*min(winhr)*1.2)) { # Calculate values
-                  exfi = 0
                   for (winhr_value in winhr) {
-                    if (length(varnum) > (60/ws3)*60*winhr_value*3) { # Calculate values
+                    exfi = collectfi[which(winhr == winhr_value)]
+                    if (length(varnum) > (60/ws3)*60*winhr_value*1.2) { # Calculate values
                       # Time window for L5 & M5 analysis
-                      t0_LFMF = L5M5window[1] #start in 24 hour clock hours
-                      t1_LFMF = L5M5window[2]+(winhr_value-(M5L5res/60)) #end in 24 hour clock hours (if a value higher than 24 is chosen, it will take early hours of previous day to complete the 5 hour window
-                      ML5 = g.getM5L5(varnum,ws3,t0_LFMF,t1_LFMF,M5L5res,winhr_value, qM5L5=qM5L5)
+                      # t0_LFMF =  (anwi_t0[anwi_index]-1)/(60*(60/ws3)) #L5M5window[1] #start in 24 hour clock hours
+                      # t1_LFMF = anwi_t1[anwi_index]/(60*(60/ws3)) + (winhr_value-(M5L5res/60)) # L5M5window[2] #end in 24 hour clock hours (if a value higher than 24 is chosen, it will take early hours of previous day to complete the 5 hour window
+                      t0_LFMF =  1 #start
+                      t1_LFMF = length(varnum)/(60*(60/ws3)) + (winhr_value-(M5L5res/60)) # L5M5window[2] #end in 24 hour clock hours (if a value higher than 24 is chosen, it will take early hours of previous day to complete the 5 hour window
+                      ML5 = g.getM5L5(varnum,ws3,t0_LFMF,t1_LFMF,M5L5res,winhr_value, qM5L5=qM5L5, 
+                                      iglevels=iglevels, MX.ig.min.dur=MX.ig.min.dur)
                       ML5colna = colnames(ML5)
                       ML5 = as.numeric(ML5)
                       if (anwi_index > 1) {
-                        L5M5shift = qwindow[anwi_index - 1]
+                        L5M5shift = qwindow_values_backup[anwi_index - 1] #qwindow
                       } else {
                         L5M5shift = 0
                       }
                       if (length(ML5) > 3) {
                         ML5 = as.numeric(ML5)
                         ML5[c(1,3)] = ML5[c(1,3)] + L5M5shift
-                        daysummary[di,(exfi+fi):(exfi+fi+length(ML5)-1)] = ML5
+                        daysummary[di,(exfi):(exfi+length(ML5)-1)] = ML5
                       } else {
-                        daysummary[di,(exfi+fi):(exfi+fi+length(ML5)-1)] = ""
+                        daysummary[di,(exfi):(exfi+length(ML5)-1)] = ""
                       }
                     } else {
-                      daysummary[di,(exfi+fi):(exfi+fi+(4*length(winhr))-1+(length(qM5L5)*2))] = ""
+                      daysummary[di,(exfi):(exfi+(4*length(winhr))-1+(length(qM5L5)*2))] = ""
                     }
                     # (Below) 4 is the length of ML5 and then 2 extra variables for every qM5L5 value
                     # winhr is not considered because we are in the winhr loop:
@@ -332,31 +425,23 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
                   }
                   
                 } else {
-                  daysummary[di,fi:(fi+(4*length(winhr))-1+(length(qM5L5)*2))] = ""
+                  daysummary[di,collectfi] = ""
                 }
-                for (winhr_value in winhr) { # Variable (column) names
-                  ML5colna = c(paste0("L",winhr_value,"hr"), paste0("L",winhr_value), 
-                               paste0("M",winhr_value,"hr"), paste0("M",winhr_value))
-                  if (length(qM5L5) > 0) {
-                    ML5colna = c(ML5colna,
-                                 paste0("L",winhr_value,"_q",round(qM5L5 *100)), 
-                                 paste0("M",winhr_value,"_q",round(qM5L5 *100)))
-                  }
-                  # add metric name and timewindow name
-                  ds_names[fi:(fi-1+length(ML5colna))] = paste0(ML5colna,"_", colnames(metashort)[mi], "_mg",L5M5window_name)
-                  fi=fi+length(ML5colna)
+                if (anwindices[1] == 1 & length(anwindices) > 6*60*(60/ws3)) { # only derive if 1-6am falls within window
+                  fi = correct_fi(di, ds_names, fi, varname = paste0("mean_",colnames(metashort)[mi],"_mg_1-6am"))
+                  daysummary[di,fi] = mean(varnum[((1*60*(60/ws3))+1):(6*60*(60/ws3))]) * 1000#from 1am to 6am
+                  ds_names[fi] = paste0("mean_",colnames(metashort)[mi],"_mg_1-6am"); fi=fi+1
                 }
-                daysummary[di,fi] = mean(varnum[((1*60*(60/ws3))+1):(6*60*(60/ws3))]) * 1000#from 1am to 6am
-                ds_names[fi] = paste0("mean_",colnames(metashort)[mi],"_mg_1-6am"); fi=fi+1
                 if (anwi_nameindices[anwi_index] == "") { # for consistency with previous GGIR version
                   anwi_nameindices[anwi_index] = "_24hr"
                 }
+                cn_metashort = colnames(metashort)
+                fi = correct_fi(di, ds_names, fi, varname = paste0("mean_",cn_metashort[mi],"_mg",anwi_nameindices[anwi_index]))
                 if (length(varnum) > 0) {
                   daysummary[di,fi] = mean(varnum) * 1000;
                 } else {
                   daysummary[di,fi] = ""
                 }
-                cn_metashort = colnames(metashort)
                 ds_names[fi] = paste0("mean_",cn_metashort[mi],"_mg",anwi_nameindices[anwi_index]); fi=fi+1
                 if (anwi_nameindices[anwi_index] == "_24hr") {
                   anwi_nameindices[anwi_index] = ""
@@ -371,6 +456,7 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
                     tmp2 = as.character(unlist(strsplit(tmp1,"%")))
                     namesq46[rq46i] = paste0("p",tmp2,"_",colnames(metashort)[mi],"_mg",anwi_nameindices[anwi_index]) # t_TWDI[1],"-",t_TWDI[2],"h",sep="")
                   }
+                  fi = correct_fi(di, ds_names, fi, varname = namesq46[1])
                   if (length(varnum) > 0) {
                     daysummary[di,fi:(fi+(length(qlevels)-1))] = q46
                   } else {
@@ -390,6 +476,7 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
                   for (rq47i in 1:length(rownames(q47))) {
                     namesq47[rq47i] = paste0(rownames(q47)[rq47i],"_",colnames(metashort)[mi],"_mg",anwi_nameindices[anwi_index]) #t_TWDI[1],"-",t_TWDI[2],"h",sep="")
                   }
+                  fi = correct_fi(di, ds_names, fi, varname = namesq47[1])
                   if (length(varnum) > 0) {
                     daysummary[di,fi:(fi+(length(q48)-1))] = q48
                   } else {
@@ -398,7 +485,6 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
                   ds_names[fi:(fi+(length(q48)-1))] = namesq47
                   fi = fi+length(q48)
                 }
-                
                 if (doiglevels == TRUE) { # intensity gradient (as described by Alex Rowlands 2018)
                   q49 = c()
                   q50 = cut((varnum*1000),breaks = iglevels,right=FALSE)
@@ -407,12 +493,14 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
                   x_ig = zoo::rollmean(iglevels,k=2)
                   y_ig = q49
                   igout = g.intensitygradient(x_ig, y_ig)
+                  varnameig = paste0(c("ig_gradient","ig_intercept","ig_rsquared"),paste0("_",colnames(metashort)[mi], anwi_nameindices[anwi_index]))
+                  fi = correct_fi(di, ds_names, fi, varname = varnameig[1])
                   if (length(varnum) > 0) {
                     daysummary[di,fi:(fi+2)] = as.vector(unlist(igout))
                   } else {
                     daysummary[di,fi:(fi+2)] = rep("",3)
                   }
-                  ds_names[fi:(fi+2)] = paste0(c("ig_gradient","ig_intercept","ig_rsquared"),paste0("_",colnames(metashort)[mi], anwi_nameindices[anwi_index]))
+                  ds_names[fi:(fi+2)] = varnameig
                   fi = fi+3
                 }
                 #=========================================
@@ -464,19 +552,25 @@ g.analyse.perday = function(selectdaysfile, ndays, firstmidnighti, time, nfeatur
                                            paste0("MVPA_E",ws3,"S_B",mvpadur[2],"M",(boutcriter * 100),"%_T",mvpathreshold[mvpai]),
                                            paste0("MVPA_E",ws3,"S_B",mvpadur[3],"M",(boutcriter * 100),"%_T",mvpathreshold[mvpai]))
                     for (fillds in 1:6) {
+                      mvpavarname = paste(mvpanames[fillds,mvpai],"_",colnames(metashort)[mi] ,anwi_nameindices[anwi_index],sep="")
+                      fi = correct_fi(di, ds_names, fi, varname = mvpavarname)
                       daysummary[di,fi] = mvpa[fillds]
-                      ds_names[fi] = paste(mvpanames[fillds,mvpai],"_",colnames(metashort)[mi] ,anwi_nameindices[anwi_index],sep=""); fi=fi+1
+                      ds_names[fi] = mvpavarname; fi=fi+1
                     }
                   }
                 }
               }
               if (mi %in% ExtFunColsi == TRUE) { # INSERT HERE VARIABLES DERIVED WITH EXTERNAL FUNCTION
                 if (myfun$reporttype == "event") { # For the event report type we take the sum
+                  varnameevent = paste0(colnames(metashort)[mi],"_sum",anwi_nameindices[anwi_index],sep="")
+                  fi = correct_fi(di, ds_names, fi, varname = varnameevent)
                   daysummary[di,fi] = sum(varnum)
-                  ds_names[fi] = paste0(colnames(metashort)[mi],"_sum",anwi_nameindices[anwi_index],sep=""); fi=fi+1
+                  ds_names[fi] = varnameevent; fi=fi+1
                 } else if (myfun$reporttype == "scalar") { # For the scalar report type we take the mean
+                  varnamescalar = paste0(colnames(metashort)[mi],"_mean",anwi_nameindices[anwi_index],sep="")
+                  fi = correct_fi(di, ds_names, fi, varname = varnamescalar)
                   daysummary[di,fi] = mean(varnum)
-                  ds_names[fi] = paste0(colnames(metashort)[mi],"_mean",anwi_nameindices[anwi_index],sep=""); fi=fi+1
+                  ds_names[fi] = varnamescalar; fi=fi+1
                 } else if (myfun$reporttype == "type") { # For type we calculate time spent in each class 
                   # Not implemented yet
                 }
