@@ -8,9 +8,14 @@ g.part2 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy = 1, hrs.d
                    window.summary.size=10,dayborder=0,bout.metric=2,closedbout=FALSE,desiredtz="",
                    IVIS_windowsize_minutes = 60, IVIS_epochsize_seconds = 3600, iglevels = c(),
                    IVIS.activity.metric=1, TimeSegments2ZeroFile=c(), qM5L5  = c(), do.parallel = TRUE,
-                   myfun=c()) {
+                   myfun=c(), MX.ig.min.dur=10) {
   snloc= 1
-  qwindow = qwindow[order(qwindow)]
+  if (is.numeric(qwindow)) {
+    qwindow = qwindow[order(qwindow)]
+  } else if (is.character(qwindow)) { 
+    qwindow = g.conv.actlog(qwindow)
+    # This will be an object with numeric qwindow values for all individuals and days
+  }  
   #---------------------------------
   # Specifying directories with meta-data and extracting filenames
   path = paste0(metadatadir,"/meta/basic/")  #values stored per long epoch, e.g. 15 minutes
@@ -165,7 +170,7 @@ g.part2 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy = 1, hrs.d
                         window.summary.size=window.summary.size,dayborder=dayborder,bout.metric=bout.metric,closedbout=closedbout,
                         desiredtz=desiredtz,IVIS_windowsize_minutes = IVIS_windowsize_minutes,
                         IVIS_epochsize_seconds = IVIS_epochsize_seconds, iglevels = iglevels,
-                        IVIS.activity.metric= IVIS.activity.metric, qM5L5  = qM5L5, myfun=myfun)
+                        IVIS.activity.metric= IVIS.activity.metric, qM5L5  = qM5L5, myfun=myfun, MX.ig.min.dur=MX.ig.min.dur)
         name=as.character(unlist(strsplit(fnames[i],"eta_"))[2])
         if (epochvalues2csv==TRUE) {
           if (length(IMP$metashort) > 0) {
@@ -223,16 +228,4 @@ g.part2 = function(datadir=c(),metadatadir=c(),f0=c(),f1=c(),strategy = 1, hrs.d
       }
     }
   }
-  SI = sessionInfo()
-  sessionInfoFile = paste(metadatadir,"/results/QC/sessioninfo_part2.RData",sep="")
-  if (file.exists(sessionInfoFile)) {
-    FI = file.info(sessionInfoFile)
-    timesincecreation = abs(as.numeric(difftime(FI$ctime,Sys.time(),units="secs")))
-    # if file is older than 2 hours plus a random number of seconds (max 1 hours) then overwrite it
-    if (timesincecreation > (2*3600 + (sample(seq(1,3600,by=0.1),size = 1)))) {
-      save(SI,file=sessionInfoFile)
-    }
-  } else {
-    save(SI,file=sessionInfoFile)
-  }
 }
