@@ -7,6 +7,7 @@ get_nw_clip_block_params = function(chunksize, dynrange, monc, rmc.noise=c(), sf
   if (monc == 4 & dformat == 4) blocksize = round(blocksize * 1.0043)
   if (monc == 4 & dformat == 2) blocksize = round(blocksize)
   if (monc == 5) blocksize = sf * 60 * 1440
+  if (monc == 6 & dformat == 2) blocksize = round(blocksize)
 
   #Clipping threshold: estimate number of data points of clipping based on raw data at about 87 Hz
   if (length(dynrange) > 0) {
@@ -22,11 +23,13 @@ get_nw_clip_block_params = function(chunksize, dynrange, monc, rmc.noise=c(), sf
       clipthres = 7.5 # hard coded assumption that dynamic range is 8g
     } else if (monc == 5) {
       clipthres = 15.5 # hard coded assumption that dynamic range is 16g
+    } else if (monc == 6) {
+      clipthres = 7.5
     } else if (monc == 0) {
       clipthres = rmc.dynamic_range
     }
   }
-  # Nonwear threshold: #non-wear criteria are moncitor specific
+  # Nonwear threshold: #non-wear criteria are monitor specific
   racriter = 0.15 #very likely irrelevant parameters, but leave in for consistency
   if (monc == 1) {
     sdcriter = 0.003
@@ -39,6 +42,9 @@ get_nw_clip_block_params = function(chunksize, dynrange, monc, rmc.noise=c(), sf
     sdcriter = 0.013 #ADJUSTMENT NEEDED FOR Axivity???????????
   } else if (monc == 5) {
     sdcriter = 0.013 #ADJUSTMENT NEEDED FOR MOVISENS???????????
+  } else if (monc == 6) {
+    sdcriter = 0.013
+    racriter = 0.20
   } else if (monc == 0) {
     if (length(rmc.noise) == 0) {
       warning("Argument rmc.noise not specified, please specify expected noise level in g-units")
