@@ -3,6 +3,6 @@ context("create_test_sleeplog_csv")
 test_that("create_test_sleeplog_csv produces a file", {
   create_test_sleeplog_csv()
   fn = "testsleeplogfile.csv"
-  expect_that(file.exists(fn),is_true())
+  expect_true(file.exists(fn))
   if (file.exists(fn)) file.remove(fn)
 })
\ No newline at end of file
